Documentation
¶
Overview ¶
package dashapi defines data structures used in dashboard communication and provides client interface.
Index ¶
- func Query(client, addr, key, method string, ctor RequestCtor, doer RequestDoer, ...) error
- type BugReport
- type BugStatus
- type BugUpdate
- type BugUpdateReply
- type Build
- type BuilderPollReq
- type BuilderPollResp
- type Crash
- type CrashID
- type Dashboard
- func (dash *Dashboard) BuilderPoll(manager string) (*BuilderPollResp, error)
- func (dash *Dashboard) LogError(name, msg string, args ...interface{})
- func (dash *Dashboard) NeedRepro(crash *CrashID) (bool, error)
- func (dash *Dashboard) ReportCrash(crash *Crash) (*ReportCrashResp, error)
- func (dash *Dashboard) ReportFailedRepro(crash *CrashID) error
- func (dash *Dashboard) UploadBuild(build *Build) error
- type LogEntry
- type NeedReproResp
- type PollRequest
- type PollResponse
- type ReportCrashResp
- type ReproLevel
- type RequestCtor
- type RequestDoer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Query ¶
func Query(client, addr, key, method string, ctor RequestCtor, doer RequestDoer, req, reply interface{}) error
Types ¶
type BugReport ¶
type BugReport struct {
Config []byte
ID string
ExtID string // arbitrary reporting ID forwarded from BugUpdate.ExtID
First bool // Set for first report for this bug.
Title string
Maintainers []string
CC []string // additional CC emails
OS string
Arch string
VMArch string
CompilerID string
KernelRepo string
KernelBranch string
KernelCommit string
KernelConfig []byte
Log []byte
Report []byte
ReproC []byte
ReproSyz []byte
}
BugReport describes a single bug. Used by dashboard external reporting.
type BugUpdateReply ¶
type Build ¶
type Build struct {
Manager string
ID string
OS string
Arch string
VMArch string
SyzkallerCommit string
CompilerID string
KernelRepo string
KernelBranch string
KernelCommit string
KernelConfig []byte
Commits []string // see BuilderPoll
}
Build describes all aspects of a kernel build.
type BuilderPollReq ¶
type BuilderPollReq struct {
Manager string
}
type BuilderPollResp ¶
type BuilderPollResp struct {
PendingCommits []string
}
type Crash ¶
type Crash struct {
BuildID string // refers to Build.ID
Title string
Maintainers []string
Log []byte
Report []byte
// The following is optional and is filled only after repro.
ReproOpts []byte
ReproSyz []byte
ReproC []byte
}
Crash describes a single kernel crash (potentially with repro).
type Dashboard ¶
func (*Dashboard) BuilderPoll ¶
func (dash *Dashboard) BuilderPoll(manager string) (*BuilderPollResp, error)
func (*Dashboard) ReportCrash ¶
func (dash *Dashboard) ReportCrash(crash *Crash) (*ReportCrashResp, error)
func (*Dashboard) ReportFailedRepro ¶
ReportFailedRepro notifies dashboard about a failed repro attempt for the crash.
func (*Dashboard) UploadBuild ¶
type NeedReproResp ¶
type NeedReproResp struct {
NeedRepro bool
}
type PollRequest ¶
type PollRequest struct {
Type string
}
type PollResponse ¶
type PollResponse struct {
Reports []*BugReport
}
type ReportCrashResp ¶
type ReportCrashResp struct {
NeedRepro bool
}
type ReproLevel ¶
type ReproLevel int
const ( ReproLevelNone ReproLevel = iota ReproLevelSyz ReproLevelC )
Click to show internal directories.
Click to hide internal directories.