Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Manager ¶
type Manager struct {
Connected time.Time
Added int
Deleted int
New int
SentRepros int
RecvRepros int
Calls map[string]struct{}
Corpus *db.DB
// contains filtered or unexported fields
}
Manager represents one syz-manager instance.
type State ¶
type State struct {
Corpus *db.DB
Repros *db.DB
Managers map[string]*Manager
// contains filtered or unexported fields
}
State holds all internal syz-hub state including corpus, reproducers and information about managers. It is persisted to and can be restored from a directory.
Click to show internal directories.
Click to hide internal directories.